Hello community,
here is the log from the commit of package rubygem-activejob-4_2 for
openSUSE:Factory checked in at 2017-03-21 22:50:31
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/rubygem-activejob-4_2 (Old)
and /work/SRC/openSUSE:Factory/.rubygem-activejob-4_2.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Package is "rubygem-activejob-4_2"
Tue Mar 21 22:50:31 2017 rev:12 rq:479677 version:4.2.8
Changes:
--------
---
/work/SRC/openSUSE:Factory/rubygem-activejob-4_2/rubygem-activejob-4_2.changes
2016-08-25 09:54:20.000000000 +0200
+++
/work/SRC/openSUSE:Factory/.rubygem-activejob-4_2.new/rubygem-activejob-4_2.changes
2017-03-21 22:50:31.850455343 +0100
@@ -1,0 +2,10 @@
+Wed Feb 22 05:29:40 UTC 2017 - [email protected]
+
+- updated to version 4.2.8
+ see installed CHANGELOG.md
+
+ ## Rails 4.2.8 (February 21, 2017) ##
+
+ * No changes.
+
+-------------------------------------------------------------------
Old:
----
activejob-4.2.7.1.gem
New:
----
activejob-4.2.8.gem
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Other differences:
------------------
++++++ rubygem-activejob-4_2.spec ++++++
--- /var/tmp/diff_new_pack.GpxkqF/_old 2017-03-21 22:50:32.602349046 +0100
+++ /var/tmp/diff_new_pack.GpxkqF/_new 2017-03-21 22:50:32.606348481 +0100
@@ -1,7 +1,7 @@
#
# spec file for package rubygem-activejob-4_2
#
-# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
@@ -24,7 +24,7 @@
#
Name: rubygem-activejob-4_2
-Version: 4.2.7.1
+Version: 4.2.8
Release: 0
%define mod_name activejob
%define mod_full_name %{mod_name}-%{version}
++++++ activejob-4.2.7.1.gem -> activejob-4.2.8.gem ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' old/CHANGELOG.md new/CHANGELOG.md
--- old/CHANGELOG.md 2016-08-11 00:25:29.000000000 +0200
+++ new/CHANGELOG.md 2017-02-21 17:07:02.000000000 +0100
@@ -1,3 +1,8 @@
+## Rails 4.2.8 (February 21, 2017) ##
+
+* No changes.
+
+
## Rails 4.2.7 (July 12, 2016) ##
* No changes.
Binary files old/checksums.yaml.gz and new/checksums.yaml.gz differ
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' old/lib/active_job/gem_version.rb
new/lib/active_job/gem_version.rb
--- old/lib/active_job/gem_version.rb 2016-08-11 00:25:29.000000000 +0200
+++ new/lib/active_job/gem_version.rb 2017-02-21 17:07:02.000000000 +0100
@@ -7,8 +7,8 @@
module VERSION
MAJOR = 4
MINOR = 2
- TINY = 7
- PRE = "1"
+ TINY = 8
+ PRE = nil
STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
end
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' old/metadata new/metadata
--- old/metadata 2016-08-11 00:25:29.000000000 +0200
+++ new/metadata 2017-02-21 17:07:02.000000000 +0100
@@ -1,14 +1,14 @@
--- !ruby/object:Gem::Specification
name: activejob
version: !ruby/object:Gem::Version
- version: 4.2.7.1
+ version: 4.2.8
platform: ruby
authors:
- David Heinemeier Hansson
autorequire:
bindir: bin
cert_chain: []
-date: 2016-08-10 00:00:00.000000000 Z
+date: 2017-02-21 00:00:00.000000000 Z
dependencies:
- !ruby/object:Gem::Dependency
name: activesupport
@@ -16,14 +16,14 @@
requirements:
- - '='
- !ruby/object:Gem::Version
- version: 4.2.7.1
+ version: 4.2.8
type: :runtime
prerelease: false
version_requirements: !ruby/object:Gem::Requirement
requirements:
- - '='
- !ruby/object:Gem::Version
- version: 4.2.7.1
+ version: 4.2.8
- !ruby/object:Gem::Dependency
name: globalid
requirement: !ruby/object:Gem::Requirement
@@ -98,9 +98,8 @@
version: '0'
requirements: []
rubyforge_project:
-rubygems_version: 2.6.6
+rubygems_version: 2.6.10
signing_key:
specification_version: 4
summary: Job framework with pluggable queues.
test_files: []
-has_rdoc:
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn'
'--exclude=.svnignore' old/lib/active_job/arguments.rb
new/lib/active_job/arguments.rb
--- old/lib/active_job/arguments.rb 2016-08-11 00:25:29.000000000 +0200
+++ new/lib/active_job/arguments.rb 2017-02-21 17:07:02.000000000 +0100
@@ -15,7 +15,7 @@
end
# Raised when an unsupported argument type is being set as job argument. We
# currently support NilClass, Fixnum, Float, String, TrueClass, FalseClass,
FalseClass,
# Bignum and object that can be represented as GlobalIDs (ex: Active Record).
# Also raised if you set the key for a Hash something else than a string or
# a symbol.
@@ -24,7 +24,9 @@
module Arguments
extend self
- TYPE_WHITELIST = [ NilClass, Fixnum, Float, String, TrueClass, FalseClass,
Bignum ]
+ # :nodoc:
+ TYPE_WHITELIST = [ NilClass, String, Integer, Float, BigDecimal,
TrueClass, FalseClass ]
+ TYPE_WHITELIST.push(Fixnum, Bignum) unless 1.class == Integer
# Serializes a set of arguments. Whitelisted types are returned
# as-is. Arrays/Hashes are serialized element by element.
@@ -15,7 +15,7 @@
end
# Raised when an unsupported argument type is being set as job argument. We
- # currently support NilClass, Fixnum, Float, String, TrueClass, FalseClass,
+ # currently support NilClass, Integer, Fixnum, Float, String, TrueClass,
FalseClass,
# Bignum and object that can be represented as GlobalIDs (ex: Active Record).